Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
signals/__init__.py | 0 | 0 | 0 | 100%
signals/dispatch/__init__.py | 2 | 0 | 0 | 100%
signals/dispatch/dispatcher.py | 217 | 65 | 0 | 70%
signals/global_settings.py | 1 | 0 | 0 | 100%
signals/test/__init__.py | 0 | 0 | 0 | 100%
signals/test/utils.py | 7 | 1 | 0 | 86%
signals/utils/__init__.py | 0 | 0 | 0 | 100%
signals/utils/inspect.py | 14 | 1 | 0 | 93%
tests/__init__.py | 0 | 0 | 0 | 100%
tests/settings.py | 0 | 0 | 0 | 100%
tests/test_dispatch/__init__.py | 0 | 0 | 0 | 100%
tests/test_dispatch/test_dispatch.py | 218 | 4 | 0 | 98%
Total | 459 | 71 | 0 | 85%

No items found using the specified filter.